<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>PianoPalette</name>
    <message>
        <location filename="../pianopalette.cpp" line="143"/>
        <location filename="../pianopalette.cpp" line="215"/>
        <location filename="../pianopalette.cpp" line="226"/>
        <location filename="../pianopalette.cpp" line="297"/>
        <location filename="../pianopalette.cpp" line="354"/>
        <location filename="../pianopalette.cpp" line="365"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="144"/>
        <location filename="../pianopalette.cpp" line="216"/>
        <location filename="../pianopalette.cpp" line="227"/>
        <location filename="../pianopalette.cpp" line="298"/>
        <location filename="../pianopalette.cpp" line="355"/>
        <location filename="../pianopalette.cpp" line="366"/>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="154"/>
        <location filename="../pianopalette.cpp" line="308"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="155"/>
        <location filename="../pianopalette.cpp" line="309"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="156"/>
        <location filename="../pianopalette.cpp" line="310"/>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="157"/>
        <location filename="../pianopalette.cpp" line="311"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="158"/>
        <location filename="../pianopalette.cpp" line="312"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="159"/>
        <location filename="../pianopalette.cpp" line="313"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="160"/>
        <location filename="../pianopalette.cpp" line="314"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="161"/>
        <location filename="../pianopalette.cpp" line="315"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="162"/>
        <location filename="../pianopalette.cpp" line="316"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="163"/>
        <location filename="../pianopalette.cpp" line="317"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="164"/>
        <location filename="../pianopalette.cpp" line="318"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="165"/>
        <location filename="../pianopalette.cpp" line="319"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="166"/>
        <location filename="../pianopalette.cpp" line="320"/>
        <source>13</source>
        <translation>13</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="167"/>
        <location filename="../pianopalette.cpp" line="321"/>
        <source>14</source>
        <translation>14</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="168"/>
        <location filename="../pianopalette.cpp" line="322"/>
        <source>15</source>
        <translation>15</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="169"/>
        <location filename="../pianopalette.cpp" line="323"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="194"/>
        <location filename="../pianopalette.cpp" line="333"/>
        <source>C</source>
        <translation>Do</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="195"/>
        <location filename="../pianopalette.cpp" line="334"/>
        <source>C#</source>
        <translation>Do#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="196"/>
        <location filename="../pianopalette.cpp" line="335"/>
        <source>D</source>
        <translation>Re</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="197"/>
        <location filename="../pianopalette.cpp" line="336"/>
        <source>D#</source>
        <translation>Re#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="198"/>
        <location filename="../pianopalette.cpp" line="337"/>
        <source>E</source>
        <translation>Mi</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="199"/>
        <location filename="../pianopalette.cpp" line="338"/>
        <source>F</source>
        <translation>Fa</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="200"/>
        <location filename="../pianopalette.cpp" line="339"/>
        <source>F#</source>
        <translation>Fa#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="201"/>
        <location filename="../pianopalette.cpp" line="340"/>
        <source>G</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="202"/>
        <location filename="../pianopalette.cpp" line="341"/>
        <source>G#</source>
        <translation>Sol#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="203"/>
        <location filename="../pianopalette.cpp" line="342"/>
        <source>A</source>
        <translation>La</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="204"/>
        <location filename="../pianopalette.cpp" line="343"/>
        <source>A#</source>
        <translation>La#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="205"/>
        <location filename="../pianopalette.cpp" line="344"/>
        <source>B</source>
        <translation>Si</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="228"/>
        <location filename="../pianopalette.cpp" line="367"/>
        <source>N*</source>
        <translation>N*</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="229"/>
        <location filename="../pianopalette.cpp" line="368"/>
        <source>#*</source>
        <translation>#*</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="241"/>
        <source>Single color highlight</source>
        <translation>Salientar unha soa cor</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="242"/>
        <source>A single color to highlight all note events</source>
        <translation>Unha única cor para resaltar todas as accións das notas</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="246"/>
        <source>Two colors highlight</source>
        <translation>Salientar dúas cores</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="247"/>
        <source>One color to highlight natural notes and a different one for accidentals</source>
        <translation>Unha cor para resaltar as notas naturais e outro diferente para as alteracións</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="251"/>
        <source>MIDI Channels highlight</source>
        <translation>Salientar canles MIDI</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="252"/>
        <source>A different color to highlight each MIDI channel. Enable Omni mode in the MIDI IN connection</source>
        <translation>Unha cor diferente para resaltar cada canle MIDI. Activa o modo Omni na conexión MIDI IN</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="256"/>
        <source>Chromatic scale background</source>
        <translation>Escala cromática de fondo</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="257"/>
        <location filename="../pianopalette.cpp" line="272"/>
        <source>One color for each note in the chromatic scale</source>
        <translation>Unha cor para cada nota da escala cromática</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="261"/>
        <source>Keys background</source>
        <translation>Fondo das teclas</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="262"/>
        <source>One color for natural notes and another for accidentals</source>
        <translation>Unha cor para as notas naturais e outro diferente para as alteracións</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="266"/>
        <source>Font foreground</source>
        <translation>Cor do texto</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="267"/>
        <source>Colors for note names</source>
        <translation>Cores para nomes de notas</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="271"/>
        <source>Chromatic scale highlight</source>
        <translation>Salientar escala cromática</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::FluidSettingsDialog</name>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="14"/>
        <source>FluidSynth Driver Settings</source>
        <translation>Axustes do controlador FluidSynth</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="119"/>
        <source>Sample Rate:</source>
        <translation>Frecuencia de mostraxe:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="102"/>
        <source>Period Size:</source>
        <translation>Tamaña dos período:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="148"/>
        <source># of Periods:</source>
        <translation>Núm. de períodos:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="39"/>
        <source>Audio Driver:</source>
        <translation>Controlador de son:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="158"/>
        <source>Polyphony:</source>
        <translation>Polifonía:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="85"/>
        <source>FluidSynth Version:</source>
        <translation>Versión de FluidSynth:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="65"/>
        <source>Sound Font:</source>
        <translation>Son fonte:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="112"/>
        <source>Initialization Status:</source>
        <translation>Estado de inicialización:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="174"/>
        <source>Buffer Time:</source>
        <translation>Tempo de buffer:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="184"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <source>3</source>
        <translation type="obsolete">3</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="284"/>
        <source>Modulation depth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="287"/>
        <source>Depth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="297"/>
        <location filename="../fluidsettingsdialog.ui" line="431"/>
        <source>Output amplitude</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="300"/>
        <location filename="../fluidsettingsdialog.ui" line="434"/>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="310"/>
        <source>Voice count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="313"/>
        <source>NR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="323"/>
        <source>Modulation speed in Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="326"/>
        <source>Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="418"/>
        <source>Damping amount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="421"/>
        <source>Damp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="444"/>
        <source>Room size (wet amount)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="447"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="457"/>
        <source>Stereo spread</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="460"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="52"/>
        <source>Gain:</source>
        <translation>Ganancia:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="141"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="200"/>
        <source>Chorus</source>
        <translation>Coros</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="207"/>
        <source>Reverb</source>
        <translation>Reverberación</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="178"/>
        <source>FluidSynth Initialized</source>
        <translation>FluidSynth Inicializado</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="178"/>
        <source>FluidSynth Initialization Failed</source>
        <translation>Inicialización fallida de FluidSynth</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="241"/>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="241"/>
        <source>Failed</source>
        <translation>Fallou</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="432"/>
        <source>Select SoundFont</source>
        <translation>Seleccione SoundFont</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="434"/>
        <source>SoundFont Files (*.sf2 *.sf3 *.dls)</source>
        <translation>Ficheiros SoundFont (*.sf2 *.sf3 *.dls)</translation>
    </message>
    <message>
        <source>SoundFont Files (*.sf2)</source>
        <translation type="vanished">Ficheiros SoundFont (*.sf2)</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::MacSynthSettingsDialog</name>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="14"/>
        <source>macOS Synth Driver Settings</source>
        <translation>Axustes do controlador de sintetizador de macOS</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="56"/>
        <source>SoundFont:</source>
        <translation>SoundFont:</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="76"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="83"/>
        <source>Use Internal Reverb</source>
        <translation>Usar a reverberación interna</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="90"/>
        <source>Init. Status:</source>
        <translation>Estado de inicialización:</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="69"/>
        <source>Default Apple DLS Sound Set</source>
        <translation>Sonidos DLS predeterminados de Apple</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="72"/>
        <source>DLS Synth Initialized</source>
        <translation>DLS Synth Iniciado</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="72"/>
        <source>DLS Synth Initialization Failed</source>
        <translation>Fallou a inicialización do DLS Synth</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="122"/>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="122"/>
        <source>Failed</source>
        <translation>Fallou</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="163"/>
        <source>Select SoundFont</source>
        <translation>Seleccione SoundFont</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="163"/>
        <source>SoundFont Files (*.sf2 *.dls)</source>
        <translation>Ficheiros SoundFont (*.sf2 *.dls)</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::NetworkSettingsDialog</name>
    <message>
        <location filename="../networksettingsdialog.ui" line="14"/>
        <source>Network Driver Settings</source>
        <translation>Axustes do controlador de rede</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="33"/>
        <source>Init. Status:</source>
        <translation>Estado de inicialización:</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="50"/>
        <source>Use IPv6</source>
        <translation>Usar IPv6</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="57"/>
        <source>Network Interface:</source>
        <translation>Interface de rede:</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="70"/>
        <source>Address</source>
        <translation>Enderezo</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="76"/>
        <source>Network Initialized</source>
        <translation>Rede inicializada</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="76"/>
        <source>Network Initialization Failed</source>
        <translation>Fallou a inicialización da rede</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="111"/>
        <location filename="../networksettingsdialog.cpp" line="174"/>
        <source>Any</source>
        <translation>Calquera</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="164"/>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="164"/>
        <source>Failed</source>
        <translation>Fallou</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::PianoScene</name>
    <message>
        <location filename="../pianoscene.cpp" line="1258"/>
        <location filename="../pianoscene.cpp" line="1271"/>
        <source>C</source>
        <translation>Do</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1259"/>
        <source>C♯</source>
        <translation>Do♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1260"/>
        <location filename="../pianoscene.cpp" line="1273"/>
        <source>D</source>
        <translation>Re</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1261"/>
        <source>D♯</source>
        <translation>Re♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1262"/>
        <location filename="../pianoscene.cpp" line="1275"/>
        <source>E</source>
        <translation>Mi</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1263"/>
        <location filename="../pianoscene.cpp" line="1276"/>
        <source>F</source>
        <translation>Fa</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1264"/>
        <source>F♯</source>
        <translation>Fa♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1265"/>
        <location filename="../pianoscene.cpp" line="1278"/>
        <source>G</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1266"/>
        <source>G♯</source>
        <translation>Sol♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1267"/>
        <location filename="../pianoscene.cpp" line="1280"/>
        <source>A</source>
        <translation>La</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1268"/>
        <source>A♯</source>
        <translation>La♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1269"/>
        <location filename="../pianoscene.cpp" line="1282"/>
        <source>B</source>
        <translation>Si</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1272"/>
        <source>D♭</source>
        <translation>Re♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1274"/>
        <source>E♭</source>
        <translation>Mi♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1277"/>
        <source>G♭</source>
        <translation>Sol♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1279"/>
        <source>A♭</source>
        <translation>La♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1281"/>
        <source>B♭</source>
        <translation>Si♭</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::SonivoxSettingsDialog</name>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="20"/>
        <source>Sonivox EAS Synth</source>
        <translation>Sintetizador Sonivox EAS</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="107"/>
        <source>Chorus</source>
        <translation>Coros</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="97"/>
        <source>Reverb</source>
        <translation>Reverberación</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="32"/>
        <source>SoundFont:</source>
        <translation type="unfinished">SoundFont:</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="58"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="75"/>
        <source>Sonivox Library Version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="208"/>
        <source>Buffer Time:</source>
        <translation>Tempo de buffer:</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="218"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="168"/>
        <source>Init. Status:</source>
        <translation>Estado de inicialización:</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="92"/>
        <source>Sonivox Initialized</source>
        <translation>Sonivox inicializado</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="92"/>
        <source>Sonivox Initialization Failed</source>
        <translation>Fallou a inicialización de Sonivox</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="178"/>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="178"/>
        <source>Failed</source>
        <translation>Fallou</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="200"/>
        <source>Select SoundFont</source>
        <translation type="unfinished">Seleccione SoundFont</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="200"/>
        <source>SoundFont Files (*.dls)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
